# Copyright 2022
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


REG_INGRESS_BW_LIMIT = 3
REG_MIN_BW = 4
REG_PORT = 5
REG_NET = 6
# for logging remote group rule
REG_REMOTE_GROUP = 7

INGRESS_BW_LIMIT_REG_NAME = "reg_ingress_bw_limit"
MIN_BW_REG_NAME = "reg_min_bw"
PORT_REG_NAME = "reg_port"
NET_REG_NAME = "reg_net"
REMOTE_GROUP_REG_NAME = "reg_remote_group"
